tsseg.algorithms.patss.segmentation package
===========================================

Submodules
----------

tsseg.algorithms.patss.segmentation.LogisticRegressionSegmentor module
----------------------------------------------------------------------

.. automodule:: tsseg.algorithms.patss.segmentation.LogisticRegressionSegmentor
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.patss.segmentation.Segmentor module
----------------------------------------------------

.. automodule:: tsseg.algorithms.patss.segmentation.Segmentor
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.patss.segmentation
   :members:
   :show-inheritance:
   :undoc-members:
